# Erk User Documentation

Documentation for end users of the erk tool.

## Contents

- [Project Setup](project-setup.md) - Configure erk for your repository
- [Planner Setup](planner-setup.md) - Set up planner commands
- [Queue Setup](queue-setup.md) - Configure queue for remote execution
- [Facts](facts.md) - Scratchpad for quick reference facts

## Getting Started

If you're new to erk, start with the [Project Setup](project-setup.md) guide.
